"use strict";
var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
var ServiceProvider_1 = require("../Core/ServiceProvider");
var fs = require("fs");
var _ = require("lodash");
var Debug_1 = require("../Core/Debug");
var Controller_1 = require("./Controller");
var ControllerServiceProvider = (function (_super) {
    __extends(ControllerServiceProvider, _super);
    function ControllerServiceProvider() {
        _super.apply(this, arguments);
        this.controllersPaths = "/app/controllers/";
    }
    ControllerServiceProvider.prototype.boot = function (container) {
    };
    ControllerServiceProvider.prototype.start = function (app, container) {
        var _this = this;
        var autoloader = container.resolve("AutoLoader");
        var lookupPaths = autoloader.getLookupPath();
        lookupPaths.forEach(function (path) {
            var fullpath = path + _this.controllersPaths;
            if (fs.existsSync(fullpath)) {
                var filenames = fs.readdirSync(fullpath);
                filenames.forEach(function (filename) {
                    if (_.endsWith(filename, "Controller.js")) {
                        _this.loadController(fullpath + filename, container);
                    }
                });
            }
        });
    };
    ControllerServiceProvider.prototype.loadController = function (filename, container) {
        var module = require(filename);
        for (var name_1 in module) {
            if (module.hasOwnProperty(name_1)) {
                if (module[name_1].prototype instanceof Controller_1.Controller) {
                    Debug_1.__DEBUG("Loaded controller: " + name_1);
                    container.register(name_1, module[name_1]);
                    var router = container.resolve("Router");
                    var controller = container.resolve(name_1);
                    for (var route in controller.decorate.routes) {
                        var controllerPath = (controller.decorate.path ? controller.decorate.path : name_1.replace("Controller", "").toLowerCase());
                        var actionPath = (controller.decorate.routes[route].path ? controller.decorate.routes[route].path : route);
                        var methods = (controller.decorate.routes[route].method ? controller.decorate.routes[route].method : ['GET']);
                        controllerPath = controllerPath.replace("Index", "/").replace("index", "/");
                        actionPath = actionPath.replace("Index", "/").replace("index", "/");
                        var fullPath = controllerPath + actionPath;
                        fullPath = fullPath.replace("//", "/");
                        router.registerRoute(methods, fullPath, name_1 + "@" + route);
                    }
                    continue;
                }
                return module;
            }
        }
    };
    return ControllerServiceProvider;
}(ServiceProvider_1.ServiceProvider));
exports.ControllerServiceProvider = ControllerServiceProvider;
//# sourceMappingURL=ControllerServiceProvider.js.map