"use strict";
var fs = require("fs");
var path = require("path");
var Debug_1 = require("./Debug");
var ServiceProvider_1 = require("./ServiceProvider");
var AutoLoader = (function () {
    function AutoLoader(application, container) {
        this.application = application;
        this.container = container;
        this.lookupPaths = [
            path.normalize(__dirname + "/"),
            path.normalize(__dirname + "/../../ts-framework/"),
            path.normalize(__dirname + "/../../ts-framework-tests/"),
            path.normalize(__dirname + "/../node_modules/ts-framework/lib")
        ];
        this.serviceProviders = [];
        this.serviceProvidersFiles = [];
    }
    AutoLoader.prototype.getLookupPath = function () {
        return this.lookupPaths;
    };
    AutoLoader.prototype.addServiceProvider = function (serviceProvider) {
        this.serviceProvidersFiles.push(serviceProvider);
    };
    AutoLoader.prototype.loadFile = function (filename) {
        var _this = this;
        var found = false;
        var module = this.lookupPaths.forEach(function (path) {
            var file = path + filename;
            if (fs.existsSync(file)) {
                var module_1 = require(file);
                for (var name_1 in module_1) {
                    if (module_1.hasOwnProperty(name_1)) {
                        if (module_1[name_1].prototype instanceof ServiceProvider_1.ServiceProvider) {
                            Debug_1.__DEBUG("Loaded service provider: " + name_1);
                            _this.serviceProviders.push(new module_1[name_1]());
                            found = true;
                            continue;
                        }
                        return module_1;
                    }
                }
            }
        });
        if (!found) {
            Debug_1.__WARNING("File " + filename + " not found during startup");
        }
        return module;
    };
    AutoLoader.prototype.getServiceProviders = function () {
        return this.serviceProviders;
    };
    AutoLoader.prototype.load = function () {
        var _this = this;
        this.serviceProvidersFiles.forEach(function (serviceProvider) {
            _this.loadFile(serviceProvider);
        });
    };
    AutoLoader.prototype.boot = function () {
        var _this = this;
        this.serviceProviders.forEach(function (serviceProvider) {
            serviceProvider.boot(_this.container);
        });
    };
    AutoLoader.prototype.start = function () {
        var _this = this;
        this.serviceProviders.forEach(function (serviceProvider) {
            serviceProvider.start(_this.application, _this.container);
        });
    };
    return AutoLoader;
}());
exports.AutoLoader = AutoLoader;
//# sourceMappingURL=AutoLoader.js.map