"use strict";
var Response = (function () {
    function Response(rawResponse) {
        this.rawResponse = rawResponse;
    }
    Response.prototype.setStatus = function (code) {
        this.rawResponse.status(code);
        return this;
    };
    Response.prototype.getStatus = function () {
        return this.rawResponse.statusCode;
    };
    Response.prototype.setHeader = function (field, value) {
        this.rawResponse.header(field, value);
        return this;
    };
    Response.prototype.getHeader = function (field) {
        return this.rawResponse.get(field);
    };
    Response.prototype.setCookie = function (name, value, options) {
        this.rawResponse.cookie(name, value, options);
        return this;
    };
    Response.prototype.removeCookie = function (name, path) {
        if (path === void 0) { path = '/'; }
        this.rawResponse.clearCookie(name, { path: path });
        return this;
    };
    Response.prototype.setContentType = function (value) {
        this.rawResponse.type(value);
        return this;
    };
    Response.prototype.setLinks = function (links) {
        this.rawResponse.links(links);
        return this;
    };
    Response.prototype.setLocal = function (name, value) {
        this.rawResponse.locals[name] = value;
        return this;
    };
    Response.prototype.getLocal = function (name) {
        return this.rawResponse.locals[name];
    };
    Response.prototype.sendContent = function (content) {
        this.rawResponse.send(content);
        return this;
    };
    Response.prototype.sendJson = function (content) {
        this.rawResponse.json(content);
        return this;
    };
    Response.prototype.sendFile = function (path) {
        this.rawResponse.sendFile(path);
        return this;
    };
    Response.prototype.sendDownload = function (path, name) {
        this.rawResponse.download(path, name);
        return this;
    };
    Response.prototype.sendView = function (view, options) {
        this.rawResponse.render(view, options);
        return this;
    };
    Response.prototype.redirect = function (url, status) {
        if (status === void 0) { status = 302; }
        this.rawResponse.redirect(url, status);
        return this;
    };
    Response.prototype.getRawResponse = function () {
        return this.rawResponse;
    };
    return Response;
}());
exports.Response = Response;
//# sourceMappingURL=Response.js.map